"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupMembersClient = void 0;
const axios_1 = __importDefault(require("axios"));
const api_js_1 = require("../api.js");
const genericClient_js_1 = require("./genericClient.js");
const error_js_1 = require("../model/error.js");
class GroupMembersClient {
    constructor(basePath, groupUid, auth, queryOptions) {
        this.basePath = basePath;
        this.groupUid = groupUid;
        this.auth = auth;
        this.client = new genericClient_js_1.GenericClient({
            basePath: basePath,
            endpointPath: `/groups/${groupUid}/members`,
            auth: auth,
            writeTypeName: "GroupMemberWrite",
            singleResponseTypeName: "WrappedGroupMember",
            multipleResponseTypeName: "WrappedWithMetaArrayGroupMember",
            queryOptions: queryOptions,
        });
    }
    create(groupMember) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(groupMember);
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.remove(id);
        });
    }
    removeByPersonUid(personUid) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.basePath}/groups/${this.groupUid}/members?personUid=${personUid}`;
            const res = yield axios_1.default.delete(url, {
                headers: yield this.auth.getHeaders(),
                validateStatus: () => true,
            });
            if (res.status === 200) {
                const result = api_js_1.ObjectSerializer.deserialize(res.data, "WrappedGroupMember");
                return result;
            }
            else {
                throw error_js_1.CoreApiError.fromHttpResponse(res);
            }
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
}
exports.GroupMembersClient = GroupMembersClient;
