var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import axios from "axios";
import { ObjectSerializer, } from "../api.js";
import { GenericClient } from "./genericClient.js";
import { CoreApiError } from "../model/error.js";
export class GroupMembersClient {
    constructor(basePath, groupUid, auth, queryOptions) {
        this.basePath = basePath;
        this.groupUid = groupUid;
        this.auth = auth;
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: `/groups/${groupUid}/members`,
            auth: auth,
            writeTypeName: "GroupMemberWrite",
            singleResponseTypeName: "WrappedGroupMember",
            multipleResponseTypeName: "WrappedWithMetaArrayGroupMember",
            queryOptions: queryOptions,
        });
    }
    create(groupMember) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(groupMember);
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.remove(id);
        });
    }
    removeByPersonUid(personUid) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = `${this.basePath}/groups/${this.groupUid}/members?personUid=${personUid}`;
            const res = yield axios.delete(url, {
                headers: yield this.auth.getHeaders(),
                validateStatus: () => true,
            });
            if (res.status === 200) {
                const result = ObjectSerializer.deserialize(res.data, "WrappedGroupMember");
                return result;
            }
            else {
                throw CoreApiError.fromHttpResponse(res);
            }
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
}
