var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { affiliationUid, client, org1Uid, person1ActiveConsentUid, person1Uid, relationUid, } from "./helpers.js";
import { ConsentPurpose, ErrorCode, WrappedAffiliation, WrappedConsent, WrappedInt, WrappedRelation, WrappedWithMetaArrayPerson, isCoreApiError, } from "../api.js";
import { assert } from "chai";
describe("Test random crud operations", () => __awaiter(void 0, void 0, void 0, function* () {
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        yield client.refreshTestData();
    }));
    it("Find person", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find();
        assert.instanceOf(result, WrappedWithMetaArrayPerson);
        assert.isAbove(result.meta.total, 0);
    }));
    it("Get person by ID lookup", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.lookupPersonId(person1Uid);
        assert.instanceOf(result, WrappedInt);
        assert.equal(result.data, 54512);
    }));
    it("Get Relation", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.relations.get(relationUid);
        assert.instanceOf(result, WrappedRelation);
    }));
    it("Update and create consent", () => __awaiter(void 0, void 0, void 0, function* () {
        const consent = yield client.consents.get(person1ActiveConsentUid);
        yield client.consents.update(consent.data.uid, {
            orgUid: consent.data.orgUid,
            personUid: consent.data.personUid,
            purpose: consent.data.purpose,
            validFrom: consent.data.validFrom,
            validTo: new Date(),
        });
        const result = yield client.consents.create({
            orgUid: org1Uid,
            personUid: person1Uid,
            purpose: ConsentPurpose.DataSharing,
            validFrom: new Date(),
        });
        assert.instanceOf(result, WrappedConsent);
    }));
    it("Remove affiliation", () => __awaiter(void 0, void 0, void 0, function* () {
        const res = yield client.affiliations.remove(affiliationUid);
        assert.instanceOf(res, WrappedAffiliation);
        try {
            yield client.affiliations.get(affiliationUid);
            assert.fail("Should not find affiliation");
        }
        catch (err) {
            if (!isCoreApiError(err))
                throw Error("Invalid error type");
            assert.equal(err.details.code, ErrorCode.NotFound);
        }
    }));
}));
